#
# spec file for package python-cma
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2020 Christoph Junghans
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# No numpy on 3.6
%define skip_python36 1
Name:           python-cma
Version:        3.3.0
Release:        1.5
Summary:        Covariance Matrix Adaptation Evolution Strategy numerical optimizer
License:        BSD-3-Clause
URL:            https://cma.gforge.inria.fr/cmaes_sourcecode_page.html
Source0:        https://github.com/CMA-ES/pycma/archive/r%{version}.tar.gz#/cma-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Recommends:     python-matplotlib
BuildArch:      noarch
%python_subpackages

%description
A stochastic numerical optimization algorithm for difficult
(non-convex, ill-conditioned, multi-modal, rugged, noisy) optimization
problems in continuous search spaces, implemented in Python.

%prep
%autosetup -n pycma-r%{version}
#Remove unneeded shebang
sed -i '1d' cma/{bbobbenchmarks.py,purecma.py,test.py}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} $python -m cma.test

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/cma*

%changelog
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 3.3.0:
  * Diagonal decoding, fmin functions with surrogate and more.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to r3.2.2:
  * Smallish fixes and improvements and a constraints use case notebook.
  * fixes plot of principal axes which were shown squared by mistake
- update to r3.2.0:
  * constraints handling via a dynamic unconstrained function instantiated
    from cma.ConstrainedFitnessAL.
  * many small improvements and fixes
- update to r3.1.0:
  * fix return value of fmin_con and make it more usable, added attribute
    best_feasible
  * polish evolution_strategy.py
  * fix a few smallish bugs
* Fri Apr 16 2021 Steve Kowalik <steven.kowalik@suse.com>
- Don't build for Python 3.6, due to no NumPy.
* Wed May 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add missing runtime dependencies, as declared in setup.py
- Format with spec-cleaner
- Make sure the tests are executed
* Mon May 11 2020 Christoph Junghans <junghans@votca.org>
- inital commit adding version 3.0.3
